/* 
// The "Structure Synth" script to generate the sphere coordinates

set maxobjects 750

{a 1 sat 1} moebius 

rule moebius { 
 12 * {rx 6 rx 1 x 1} 
 60 * {rz 3 rz 3 y 1} xbox
} 
rule xbox {
 {b 1 color #ddcb65 a 1} sphere
}

rule xbox {
 {b 1 color #7d4693 a 1} sphere
}

rule xbox {
 {b 1 color #4e5e96 a 1} sphere
}
*/

#version 3.7;

global_settings {
        #declare a_g = 2.2;
        assumed_gamma a_g
        max_trace_level 4
        noise_generator 2
} 

#include "stdinc.inc"  

#declare fac = 1;

sky_sphere {
        pigment {
                average
                pigment_map {
                        [1      function {max (min (y, 1), 0)} 
                                color_map {
                                        [0      rgb fac*2.35]
                                        [0.96   rgb fac*4.5]
                                        [1      rgb fac*13.5]
                                }
                        ]
                        [1      function {max (min (y, 1), 0)}
                                turbulence 0.2
                                color_map {
                                        [0      rgbt 1]
                                        [0.5    rgbt <fac*0.335,fac*0.77,fac*1.1,1>]
                                }
                                rotate z*-45
                        ]
                }
        }
} 

camera {
        location <10.3511,16.9673,56.6661>
        look_at <4,3,0>
        right x*16/9
        angle 88
        //focal_point <5.2,8.5,28.3> aperture 2 blur_samples 200
}
 
//__________________________________________________________________________________________________________________

#declare rng = function {pigment {granite}} 
      
#macro T807 (Color)

texture {
	aoi
	texture_map {
		[0      pigment {color srgb Color*0.5}
        	        normal {
        	                function {-100*rng (x,y,z).x} 
        	                ramp_wave 
        	                scale 40
        	                accuracy 0.0001
        	                slope_map { 
        	                        [0      <0,0>]
                                        [0.2    <1,1>]
                                        [0.2    <1,0>]
                                        [0.8    <1,0>]
                                        [0.8    <1,-1>]
                                        [1      <0,0>]
                                }
        	                bump_size 0.04
        	        }
	                finish {
	                	brilliance 7
	                	diffuse 0
	                	emission 0
	                	metallic
	                	specular 0.8
	                	roughness 0.025
	                	reflection {srgb Color}
	                	irid {0.08 thickness 0.3 turbulence 0.2}
	                }
                ]
                [0.5    pigment {color srgb 0}
        	        normal {
        	                function {-100*rng (x,y,z).x} 
        	                ramp_wave 
        	                scale 40
        	                accuracy 0.0001
        	                slope_map { 
        	                        [0      <0,0>]
                                        [0.2    <1,1>]
                                        [0.2    <1,0>]
                                        [0.8    <1,0>]
                                        [0.8    <1,-1>]
                                        [1      <0,0>]
                                }
        	                bump_size 0.04
        	        }
	                finish {
	                	brilliance 7
	                	diffuse 0
	                	metallic
	                	specular 0.8
	                	roughness 0.025
	                	reflection {0, 1}
	                	irid {0.08 thickness 0.3 turbulence 0.2}
	                }
                ]
		[1      pigment {color srgb Color*0.5}
        	        normal {
        	                function {-100*rng (x,y,z).x} 
        	                ramp_wave 
        	                scale 40
        	                accuracy 0.0001
        	                slope_map { 
        	                        [0      <0,0>]
                                        [0.2    <1,1>]
                                        [0.2    <1,0>]
                                        [0.8    <1,0>]
                                        [0.8    <1,-1>]
                                        [1      <0,0>]
                                }
        	                bump_size 0.04
        	        }
	                finish {
	                	brilliance 7
	                	diffuse 0
	                	emission 0
	                	metallic
	                	specular 0.8
	                	roughness 0.025
	                	reflection {srgb Color}
	                	irid {0.08 thickness 0.3 turbulence 0.2}
	                }
                ]
	}        
}

#end

#declare F_ = 
function {
        pigment {
                crackle 
                metric 0.05 
                form x/1e9 
                poly_wave 0.4 
                color_map {
                        [0      rgb 1]
                        [1      rgb 0]
                }
        }
}

#macro T1228 (col)

material {
	texture {
                pigment {color srgb <col.x,col.y,col.z>*0.5}
                normal {
                        function {F_ (x,y,z).x}
                        triangle_wave 
                        frequency 2
                }
                finish {
                        ambient 0 
                        diffuse 0.2+((col.x+col.y+col.z)/45) 
                        specular 0.6 
                        roughness 0.01 
                        reflection {srgb <col.x,col.y,col.z>*0.14+0.21}
                        irid {0.6 thickness 0.3 turbulence 0.2} 
                        brilliance -0.15 
                        metallic 0.4
                }
        }
        interior {ior 1.5}
}

#end 
                                              
#declare ridge_f = function {(f_ridged_mf ((4+x)/0.3, y/0.3, z/0.3, 0.5, 2.7, 4, 1, 1.5, 0)-1.8)*0.0125}
                
#macro T810 (col)

texture {
	function {ridge_f (x,y,z)} 
	texture_map {
	        [0.98   pigment {
	                	aoi
	                	color_map {
	                		[0      srgb 1]
	                		[0.5    srgb col]
	                		[1      srgb 1]
	                	}
	                }
                        normal {function {ridge_f (x,y,z)} -100 accuracy 0.0001 poly_wave  0.5}
	                finish {
	                	specular albedo 0.25
	                	metallic
	                	roughness 0.025
	                	diffuse 0.6
	                	brilliance 2
	                	reflection {0.5 metallic}
	                	conserve_energy
	                	irid {0.8 thickness 0.1 turbulence 0.5}
	                }
	        ]
	        [1      pigment {color srgb <0.7,0.7,0.7>}
		        finish {
		        	diffuse 0.2
		        	brilliance 4
		        	reflection {0.5, 1 fresnel on}
		        	conserve_energy
		        	phong 2
		        	phong_size 200
		        	specular 0.3
		        	roughness 0.05
		        }
		        normal {
		        	average
		        	normal_map {
		        		[1      granite 0.14 scale 0.0007 accuracy 0.1]
		        		[1      function {ridge_f (x,y,z)} -200 accuracy 0.0001 poly_wave 0.5]
		        	}
		        } 
                ]
	}
}

#end  

//__________________________________________________________________________________________________________________

#declare nw = 
union {	
object {   
  sphere {<1.39547, 1.48711, 0.621202>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<2.39547, 1.46498, 0.740597>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<3.39547, 1.42847, 0.856405>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<4.39547, 1.37811, 0.9669>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<5.39547, 1.31467, 1.07043>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<6.39547, 1.23907, 1.16547>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<7.39547, 1.15247, 1.25058>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<8.39547, 1.05613, 1.3245>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<9.39547, 0.951504, 1.38613>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<10.3955, 0.840147, 1.43455>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<11.3955, 0.723719, 1.46903>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<12.3955, 0.603956, 1.48907>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<1.18756, 2.45797, 0.740408>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<2.18756, 2.41407, 0.977232>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<3.18756, 2.34165, 1.20694>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<4.18756, 2.24176, 1.42611>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<5.18756, 2.11592, 1.63148>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<6.18756, 1.96598, 1.81997>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<7.18756, 1.79419, 1.98879>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<8.18756, 1.6031, 2.13542>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<9.18756, 1.39557, 2.25766>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<10.1876, 1.17469, 2.3537>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<11.1876, 0.943755, 2.42211>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<12.1876, 0.706201, 2.46186>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<0.878543, 3.40193, 0.856313>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<1.87854, 3.33688, 1.20731>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<2.87854, 3.22953, 1.54777>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<3.87854, 3.0815, 1.87261>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<4.87854, 2.89498, 2.17698>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<5.87854, 2.67275, 2.45636>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<6.87854, 2.41814, 2.70656>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<7.87854, 2.13493, 2.92388>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<8.87854, 1.82735, 3.10506>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<9.87854, 1.49997, 3.2474>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<10.8785, 1.1577, 3.34879>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<11.8785, 0.805614, 3.40771>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<0.471806, 4.30867, 0.967646>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<1.47181, 4.22329, 1.42832>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<2.47181, 4.0824, 1.87516>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<3.47181, 3.88811, 2.30149>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<4.47181, 3.64331, 2.70097>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<5.47181, 3.35165, 3.06764>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<6.47181, 3.01748, 3.39603>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<7.47181, 2.64578, 3.68124>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<8.47181, 2.24209, 3.91903>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<9.47181, 1.81243, 4.10586>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<10.4718, 1.3632, 4.23892>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<11.4718, 0.901105, 4.31625>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-0.0281936, 5.16824, 1.07319>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<0.971806, 5.06359, 1.63783>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<1.97181, 4.89091, 2.18551>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<2.97181, 4.65277, 2.70806>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<3.97181, 4.35272, 3.1977>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<4.97181, 3.99523, 3.64712>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<5.97181, 3.58564, 4.04962>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<6.97181, 3.13005, 4.39921>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<7.97181, 2.63525, 4.69067>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<8.97181, 2.10862, 4.91966>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<9.97181, 1.55801, 5.08275>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<10.9718, 0.99163, 5.17753>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-0.615979, 5.97123, 1.17178>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<0.384021, 5.84857, 1.83355>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<1.38402, 5.64619, 2.47544>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<2.38402, 5.36709, 3.08787>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<3.38402, 5.01542, 3.66173>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<4.38402, 4.59645, 4.18846>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<5.38402, 4.11641, 4.6602>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<6.38402, 3.58245, 5.06992>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<7.38402, 3.00254, 5.41151>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<8.38402, 2.38532, 5.67988>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<9.38402, 1.74, 5.87104>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<10.384, 1.0762, 5.98212>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-1.28511, 6.70883, 1.26235>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-0.285109, 6.56964, 2.01333>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<0.714891, 6.33997, 2.74176>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<1.71489, 6.02324, 3.43676>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<2.71489, 5.62417, 4.08798>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<3.71489, 5.14871, 4.68572>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<4.71489, 4.60395, 5.22106>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<5.71489, 3.99801, 5.68601>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<6.71489, 3.33992, 6.07366>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<7.71489, 2.63949, 6.37821>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<8.71489, 1.90717, 6.59513>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<9.71489, 1.15387, 6.72119>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-2.02825, 7.37297, 1.34389>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-1.02825, 7.2189, 2.17521>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-0.0282539, 6.96466, 2.98155>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<0.971746, 6.61405, 3.7509>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<1.97175, 6.17229, 4.47178>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<2.97175, 5.64597, 5.13346>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<3.97175, 5.04294, 5.72605>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<4.97175, 4.37218, 6.24075>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<5.97175, 3.6437, 6.66986>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<6.97175, 2.86835, 7.00699>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<7.97175, 2.0577, 7.24712>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<8.97175, 1.22382, 7.38666>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-2.83727, 7.95638, 1.41553>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-1.83727, 7.78922, 2.31741>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-0.837271, 7.51341, 3.19219>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<0.16273, 7.13303, 4.02685>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<1.16273, 6.65378, 4.80892>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<2.16273, 6.08278, 5.52676>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<3.16273, 5.42856, 6.16966>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<4.16273, 4.70087, 6.72804>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<5.16273, 3.91055, 7.19358>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<6.16273, 3.06939, 7.55933>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<7.16273, 2.18992, 7.81984>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<8.16273, 1.28526, 7.97122>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-3.7033, 8.45265, 1.47646>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-2.7033, 8.27437, 2.43837>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-1.7033, 7.9802, 3.37138>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-0.703295, 7.57451, 4.26158>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<0.296705, 7.06335, 5.09571>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<1.2967, 6.45436, 5.86133>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<2.2967, 5.75659, 6.54702>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<3.2967, 4.98046, 7.14256>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<4.2967, 4.13754, 7.63908>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<5.2967, 3.2404, 8.02917>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<6.2967, 2.30239, 8.30702>, 0.500001 }
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<7.2967, 1.33752, 8.46848>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-4.61684, 8.85636, 1.52603>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-3.61684, 8.66903, 2.53677>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-2.61684, 8.35992, 3.51714>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-1.61684, 7.93363, 4.45253>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-0.616841, 7.39653, 5.329>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<0.383159, 6.75662, 6.13349>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<1.38316, 6.02344, 6.85398>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<2.38316, 5.20791, 7.47976>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<3.38316, 4.3222, 8.00148>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<4.38316, 3.37951, 8.41138>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<5.38316, 2.39389, 8.70333>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<6.38316, 1.38004, 8.87299>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-5.5679, 9.16307, 1.56369>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-4.5679, 8.96887, 2.61153>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-3.5679, 8.64841, 3.62788>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-2.5679, 8.20648, 4.59761>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-1.5679, 7.64967, 5.50625>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-0.567897, 6.98626, 6.34026>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<0.432103, 6.22617, 7.0872>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<1.4321, 5.38071, 7.73595>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<2.4321, 4.46249, 8.27682>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<3.4321, 3.4852, 8.70176>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<4.4321, 2.4634, 9.00443>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<5.4321, 1.41234, 9.18032>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-6.54604, 9.36943, 1.58903>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-5.54604, 9.1706, 2.66182>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-4.54604, 8.84251, 3.70239>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-3.54604, 8.39006, 4.69522>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-2.54604, 7.81998, 5.6255>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-1.54604, 7.14077, 6.47938>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-0.546044, 6.36257, 7.24412>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<0.453956, 5.49697, 7.90831>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<1.45396, 4.55688, 8.46207>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<2.45396, 3.55631, 8.89713>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<3.45396, 2.51017, 9.20701>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<4.45396, 1.43407, 9.38709>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-7.54057, 9.47318, 1.60177>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-6.54057, 9.27202, 2.68711>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-5.54057, 8.9401, 3.73985>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-4.54057, 8.48235, 4.74429>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-3.54057, 7.9056, 5.68546>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-2.54057, 7.21845, 6.54932>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-1.54057, 6.43115, 7.323>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-0.540565, 5.55542, 7.99497>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<0.459435, 4.60433, 8.55521>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<1.45943, 3.59206, 8.99536>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<2.45943, 2.53369, 9.30886>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<3.45943, 1.445, 9.49104>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-8.54057, 9.47318, 1.60177>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-7.54057, 9.27202, 2.68711>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-6.54057, 8.9401, 3.73985>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-5.54056, 8.48235, 4.74429>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-4.54056, 7.9056, 5.68546>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-3.54056, 7.21845, 6.54932>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-2.54057, 6.43115, 7.323>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-1.54057, 5.55542, 7.99497>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-0.540565, 4.60433, 8.55521>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<0.459435, 3.59206, 8.99536>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<1.45943, 2.53369, 9.30886>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<2.45943, 1.445, 9.49104>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-9.53509, 9.36943, 1.58903>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-8.53509, 9.1706, 2.66182>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-7.53509, 8.84251, 3.70239>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-6.53509, 8.39005, 4.69522>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-5.53509, 7.81998, 5.6255>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-4.53509, 7.14077, 6.47938>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-3.53509, 6.36257, 7.24411>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-2.53509, 5.49697, 7.90831>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-1.53509, 4.55688, 8.46207>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-0.535086, 3.55631, 8.89713>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<0.464914, 2.51017, 9.20701>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<1.46491, 1.43407, 9.38709>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-10.5132, 9.16307, 1.56369>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-9.51323, 8.96886, 2.61153>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-8.51323, 8.64841, 3.62788>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-7.51323, 8.20648, 4.59761>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-6.51323, 7.64967, 5.50625>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-5.51323, 6.98626, 6.34026>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-4.51323, 6.22617, 7.0872>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-3.51323, 5.38071, 7.73595>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-2.51323, 4.46249, 8.27682>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-1.51323, 3.4852, 8.70176>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-0.513233, 2.4634, 9.00443>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<0.486767, 1.41234, 9.18032>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-11.4643, 8.85636, 1.52603>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-10.4643, 8.66903, 2.53677>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-9.46429, 8.35992, 3.51714>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-8.46429, 7.93363, 4.45253>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-7.46429, 7.39653, 5.329>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-6.46429, 6.75662, 6.13349>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-5.46429, 6.02344, 6.85398>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-4.46429, 5.20791, 7.47976>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-3.46429, 4.3222, 8.00148>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-2.46429, 3.37951, 8.41138>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-1.46429, 2.39389, 8.70333>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-0.464289, 1.38004, 8.87299>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-12.3778, 8.45265, 1.47646>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-11.3778, 8.27437, 2.43837>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-10.3778, 7.9802, 3.37138>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-9.37783, 7.57451, 4.26158>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-8.37783, 7.06335, 5.09571>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-7.37783, 6.45436, 5.86133>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-6.37783, 5.75659, 6.54702>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-5.37783, 4.98046, 7.14256>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-4.37783, 4.13754, 7.63908>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-3.37783, 3.2404, 8.02917>, 0.500001 }
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-2.37783, 2.30239, 8.30702>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-1.37783, 1.33752, 8.46848>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-13.2439, 7.95638, 1.41553>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-12.2439, 7.78922, 2.31741>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-11.2439, 7.5134, 3.19219>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-10.2439, 7.13303, 4.02685>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-9.24386, 6.65378, 4.80892>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-8.24386, 6.08278, 5.52676>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-7.24386, 5.42856, 6.16966>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-6.24386, 4.70087, 6.72804>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-5.24386, 3.91055, 7.19357>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-4.24386, 3.06939, 7.55933>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-3.24386, 2.18992, 7.81984>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-2.24386, 1.28526, 7.97122>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-14.0529, 7.37297, 1.3439>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-13.0529, 7.2189, 2.17521>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-12.0529, 6.96466, 2.98155>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-11.0529, 6.61405, 3.7509>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-10.0529, 6.17229, 4.47178>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-9.05287, 5.64597, 5.13346>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-8.05287, 5.04294, 5.72605>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-7.05287, 4.37218, 6.24075>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-6.05287, 3.6437, 6.66985>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-5.05287, 2.86835, 7.00699>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-4.05288, 2.0577, 7.24712>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-3.05288, 1.22382, 7.38666>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-14.796, 6.70883, 1.26235>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-13.796, 6.56964, 2.01333>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-12.796, 6.33997, 2.74176>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-11.796, 6.02324, 3.43676>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-10.796, 5.62417, 4.08798>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-9.79602, 5.14871, 4.68572>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-8.79602, 4.60395, 5.22106>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-7.79602, 3.99801, 5.68601>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-6.79602, 3.33992, 6.07365>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-5.79602, 2.63949, 6.37821>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-4.79602, 1.90717, 6.59514>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-3.79602, 1.15387, 6.72119>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-15.4651, 5.97123, 1.17178>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-14.4651, 5.84857, 1.83355>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-13.4651, 5.64619, 2.47544>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-12.4651, 5.36708, 3.08788>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-11.4651, 5.01543, 3.66173>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-10.4651, 4.59645, 4.18846>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-9.46515, 4.11641, 4.6602>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-8.46515, 3.58245, 5.06992>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-7.46515, 3.00254, 5.41151>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-6.46515, 2.38532, 5.67988>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-5.46515, 1.74, 5.87104>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-4.46515, 1.0762, 5.98212>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-16.0529, 5.16824, 1.07319>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-15.0529, 5.06359, 1.63783>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-14.0529, 4.89091, 2.18551>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-13.0529, 4.65276, 2.70807>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-12.0529, 4.35272, 3.1977>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-11.0529, 3.99523, 3.64712>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-10.0529, 3.58564, 4.04962>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-9.05293, 3.13005, 4.39921>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-8.05293, 2.63525, 4.69067>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-7.05293, 2.10862, 4.91966>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-6.05293, 1.55801, 5.08276>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-5.05293, 0.99163, 5.17753>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-16.5529, 4.30867, 0.967646>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-15.5529, 4.22329, 1.42832>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-14.5529, 4.0824, 1.87516>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-13.5529, 3.88811, 2.30149>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-12.5529, 3.64331, 2.70097>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-11.5529, 3.35165, 3.06764>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-10.5529, 3.01748, 3.39603>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-9.55293, 2.64578, 3.68124>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-8.55293, 2.24209, 3.91903>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-7.55293, 1.81243, 4.10586>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-6.55293, 1.3632, 4.23893>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-5.55293, 0.901105, 4.31625>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-16.9597, 3.40194, 0.856313>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-15.9597, 3.33688, 1.20731>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-14.9597, 3.22953, 1.54777>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-13.9597, 3.0815, 1.87261>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-12.9597, 2.89498, 2.17698>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-11.9597, 2.67275, 2.45636>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-10.9597, 2.41814, 2.70657>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-9.95967, 2.13493, 2.92388>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-8.95967, 1.82735, 3.10506>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-7.95967, 1.49997, 3.24741>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-6.95967, 1.1577, 3.3488>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-5.95967, 0.805614, 3.40771>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-17.2687, 2.45797, 0.740408>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-16.2687, 2.41407, 0.977233>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-15.2687, 2.34165, 1.20694>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-14.2687, 2.24177, 1.42611>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-13.2687, 2.11592, 1.63148>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-12.2687, 1.96598, 1.81998>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-11.2687, 1.79419, 1.98879>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-10.2687, 1.60311, 2.13542>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-9.26869, 1.39558, 2.25766>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-8.26869, 1.17469, 2.35371>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-7.26869, 0.943756, 2.42211>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-6.26869, 0.706201, 2.46187>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-17.4766, 1.48711, 0.621202>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-16.4766, 1.46498, 0.740598>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-15.4766, 1.42847, 0.856406>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-14.4766, 1.37811, 0.966903>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-13.4766, 1.31467, 1.07044>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-12.4766, 1.23908, 1.16547>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-11.4766, 1.15247, 1.25058>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-10.4766, 1.05613, 1.3245>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-9.4766, 0.951507, 1.38613>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-8.4766, 0.840149, 1.43455>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-7.4766, 0.723721, 1.46904>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-6.4766, 0.603957, 1.48908>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-17.5811, 0.500005, 0.500001>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-16.5811, 0.500003, 0.500002>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-15.5811, 0.500002, 0.500002>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-14.5811, 0.500003, 0.500004>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-13.5811, 0.500007, 0.500002>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-12.5811, 0.500004, 0.500004>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-11.5811, 0.500003, 0.500004>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-10.5811, 0.500004, 0.500005>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-9.58113, 0.500003, 0.500003>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-8.58113, 0.500002, 0.500006>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-7.58113, 0.500002, 0.500004>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-6.58113, 0.500001, 0.500006>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-17.5811, -0.492541, 0.378131>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-16.5811, -0.470292, 0.25808>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-15.5811, -0.433578, 0.141634>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-14.5811, -0.382944, 0.030533>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-13.5811, -0.319144, -0.0735744>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-12.5811, -0.24314, -0.169126>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-11.5811, -0.156056, -0.254705>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-10.5811, -0.0591885, -0.329032>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-9.58113, 0.046013, -0.391002>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-8.58113, 0.157982, -0.439686>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-7.58113, 0.275051, -0.474366>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-6.58113, 0.395473, -0.494515>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-17.4766, -1.47965, 0.25693>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-16.4766, -1.43527, 0.017484>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-15.4766, -1.36204, -0.21477>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-14.4766, -1.26105, -0.436366>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-13.4766, -1.13381, -0.644008>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-12.4766, -0.982213, -0.834591>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-11.4766, -0.808521, -1.00528>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-10.4766, -0.615318, -1.15353>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-9.4766, -0.40549, -1.27713>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-8.4766, -0.182164, -1.37423>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-7.4766, 0.0513321, -1.4434>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-6.4766, 0.291517, -1.48359>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-17.2687, -2.4505, 0.137724>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-16.2687, -2.38436, -0.219151>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-15.2687, -2.27522, -0.565306>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-14.2687, -2.12471, -0.895578>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-13.2687, -1.93506, -1.20505>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-12.2687, -1.70912, -1.4891>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-11.2687, -1.45024, -1.7435>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-10.2687, -1.16229, -1.96445>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-9.26869, -0.84956, -2.14866>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-8.26869, -0.51671, -2.29339>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-7.26869, -0.168703, -2.39648>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-6.26869, 0.189272, -2.45638>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-16.9597, -3.39447, 0.021819>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-15.9597, -3.30717, -0.449232>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-14.9597, -3.16311, -0.906134>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-13.9597, -2.96444, -1.34207>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-12.9597, -2.71412, -1.75055>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-11.9597, -2.41589, -2.12548>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-10.9597, -2.07419, -2.46127>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-9.95967, -1.69411, -2.75291>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-8.95967, -1.28133, -2.99606>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-7.95967, -0.84199, -3.18709>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-6.95967, -0.382644, -3.32316>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-5.95967, 0.0898598, -3.40222>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-16.5529, -4.30121, -0.0895141>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-15.5529, -4.19358, -0.670238>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-14.5529, -4.01598, -1.23352>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-13.5529, -3.77105, -1.77095>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-12.5529, -3.46245, -2.27454>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-11.5529, -3.09479, -2.73676>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-10.5529, -2.67353, -3.15073>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-9.55293, -2.20496, -3.51027>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-8.55293, -1.69607, -3.81003>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-7.55293, -1.15444, -4.04554>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-6.55293, -0.588147, -4.21329>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-5.55293, -0.00563169, -4.31076>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-16.0529, -5.16078, -0.195056>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-15.0529, -5.03388, -0.879749>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-14.0529, -4.82448, -1.54387>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-13.0529, -4.5357, -2.17753>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-12.0529, -4.17186, -2.77127>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-11.0529, -3.73837, -3.31624>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-10.0529, -3.24169, -3.80432>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-9.05293, -2.68924, -4.22824>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-8.05293, -2.08924, -4.58167>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-7.05293, -1.45064, -4.85934>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-6.05293, -0.78296, -5.05712>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-5.05293, -0.096156, -5.17204>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-15.4651, -5.96376, -0.29365>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-14.4651, -5.81886, -1.07547>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-13.4651, -5.57976, -1.8338>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-12.4651, -5.25002, -2.55734>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-11.4651, -4.83456, -3.23531>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-10.4651, -4.33958, -3.85758>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-9.46515, -3.77246, -4.4149>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-8.46515, -3.14163, -4.89894>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-7.46515, -2.45652, -5.3025>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-6.46515, -1.72734, -5.61956>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-5.46515, -0.96495, -5.8454>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-4.46515, -0.180721, -5.97663>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-14.796, -6.70137, -0.384217>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-13.796, -6.53993, -1.25525>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-12.796, -6.27355, -2.10012>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-11.796, -5.90618, -2.90622>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-10.796, -5.44331, -3.66156>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-9.79602, -4.89185, -4.35484>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-8.79602, -4.26, -4.97575>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-7.79602, -3.55719, -5.51504>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-6.79602, -2.7939, -5.96465>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-5.79602, -1.98151, -6.31789>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-4.79602, -1.13212, -6.5695>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-3.79602, -0.258401, -6.7157>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-14.0529, -7.36551, -0.465763>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-13.0529, -7.18919, -1.41713>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-12.0529, -6.89823, -2.33991>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-11.0529, -6.49699, -3.22036>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-10.0529, -5.99143, -4.04535>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-9.05287, -5.38911, -4.80258>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-8.05287, -4.69899, -5.48075>, 0.500001 }
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-7.05287, -3.93137, -6.06977>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-6.05287, -3.09768, -6.56085>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-5.05287, -2.21036, -6.94667>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-4.05287, -1.28264, -7.22148>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-3.05287, -0.328344, -7.38116>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-13.2439, -7.94891, -0.537396>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-12.2439, -7.75951, -1.55932>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-11.2439, -7.44698, -2.55055>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-10.2439, -7.01597, -3.49631>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-9.24386, -6.47291, -4.38249>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-8.24386, -5.82592, -5.19588>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-7.24386, -5.08461, -5.92436>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-6.24386, -4.26005, -6.55707>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-5.24386, -3.36453, -7.08457>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-4.24386, -2.4114, -7.499>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-3.24386, -1.41487, -7.7942>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-2.24386, -0.389785, -7.96573>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-12.3778, -8.44518, -0.598331>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-11.3778, -8.24466, -1.68029>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-10.3778, -7.91377, -2.72974>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-9.37783, -7.45744, -3.73104>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-8.37783, -6.88249, -4.66928>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-7.37784, -6.19749, -5.53045>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-6.37783, -5.41264, -6.30171>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-5.37783, -4.53965, -6.97158>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-4.37783, -3.59153, -7.53007>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-3.37783, -2.58241, -7.96885>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-2.37783, -1.52734, -8.28138>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-1.37783, -0.442049, -8.46299>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-11.4643, -8.84889, -0.647899>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-10.4643, -8.63931, -1.77868>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-9.46429, -8.29349, -2.8755>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-8.46429, -7.81657, -3.92199>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-7.46429, -7.21567, -4.90257>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-6.46429, -6.49975, -5.8026>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-5.46429, -5.67949, -6.60868>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-4.46429, -4.76709, -7.30878>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-3.46429, -3.77618, -7.89247>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-2.46429, -2.72152, -8.35105>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-1.46429, -1.61884, -8.67769>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-0.46429, -0.484564, -8.8675>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-10.5132, -9.1556, -0.685559>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-9.51324, -8.93915, -1.85344>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-8.51324, -8.58198, -2.98624>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-7.51324, -8.08941, -4.06707>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-6.51323, -7.4688, -5.07982>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-5.51324, -6.7294, -6.00938>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-4.51324, -5.88222, -6.8419>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-3.51323, -4.93989, -7.56497>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-2.51324, -3.91647, -8.16781>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-1.51324, -2.82721, -8.64143>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-0.513235, -1.68835, -8.97879>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<0.486765, -0.516865, -9.17482>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-9.53509, -9.36196, -0.710897>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-8.53509, -9.14088, -1.90374>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-7.53509, -8.77608, -3.06075>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-6.53509, -8.27299, -4.16467>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-5.53509, -7.63911, -5.19907>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-4.53509, -6.8839, -6.1485>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-3.53509, -6.01862, -6.99881>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-2.53509, -5.05615, -7.73734>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-1.53509, -4.01086, -8.35306>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-0.535089, -2.89832, -8.83681>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<0.464911, -1.73512, -9.18137>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<1.46491, -0.538598, -9.38159>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-8.54057, -9.46571, -0.723636>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-7.54057, -9.24231, -1.92903>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-6.54057, -8.87367, -3.09821>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-5.54057, -8.36528, -4.21375>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-4.54057, -7.72473, -5.25903>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-3.54057, -6.96158, -6.21844>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-2.54057, -6.0872, -7.0777>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-1.54057, -5.1146, -7.82399>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-0.540569, -4.05832, -8.44619>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<0.459431, -2.93407, -8.93503>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<1.45943, -1.75863, -9.28322>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<2.45943, -0.549524, -9.48555>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-7.54057, -9.46571, -0.723636>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-6.54057, -9.24231, -1.92903>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-5.54057, -8.87367, -3.09821>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-4.54057, -8.36528, -4.21375>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-3.54057, -7.72473, -5.25903>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-2.54057, -6.96158, -6.21844>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-1.54057, -6.0872, -7.0777>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-0.540569, -5.1146, -7.82399>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<0.45943, -4.05832, -8.44619>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<1.45943, -2.93407, -8.93503>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<2.45943, -1.75863, -9.28322>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<3.45943, -0.549524, -9.48555>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-6.54605, -9.36196, -0.710897>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-5.54605, -9.14088, -1.90374>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-4.54605, -8.77608, -3.06075>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-3.54605, -8.27299, -4.16467>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-2.54605, -7.63911, -5.19907>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-1.54605, -6.8839, -6.1485>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-0.546051, -6.01862, -6.99881>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<0.453952, -5.05615, -7.73733>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<1.45395, -4.01086, -8.35306>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<2.45395, -2.89832, -8.83681>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<3.45395, -1.73512, -9.18137>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<4.45395, -0.538598, -9.38159>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-5.56791, -9.1556, -0.685559>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-4.56791, -8.93915, -1.85344>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-3.56791, -8.58198, -2.98624>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-2.56791, -8.08941, -4.06707>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-1.5679, -7.4688, -5.07982>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-0.567905, -6.72939, -6.00938>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<0.432095, -5.88222, -6.8419>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<1.4321, -4.93989, -7.56497>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<2.4321, -3.91647, -8.16781>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<3.4321, -2.82721, -8.64143>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<4.4321, -1.68835, -8.97879>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<5.4321, -0.516865, -9.17482>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-4.61685, -8.84889, -0.647899>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-3.61685, -8.63931, -1.77868>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-2.61685, -8.29349, -2.8755>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-1.61685, -7.81657, -3.92199>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-0.616848, -7.21567, -4.90257>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<0.38315, -6.49975, -5.8026>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<1.38315, -5.67949, -6.60868>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<2.38315, -4.76709, -7.30878>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<3.38315, -3.77618, -7.89247>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<4.38315, -2.72152, -8.35105>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<5.38315, -1.61884, -8.67769>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<6.38315, -0.484564, -8.8675>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-3.70331, -8.44518, -0.598331>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-2.70331, -8.24466, -1.68029>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-1.70331, -7.91376, -2.72974>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-0.703307, -7.45744, -3.73104>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<0.296695, -6.88249, -4.66928>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<1.29669, -6.19749, -5.53044>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<2.29669, -5.41264, -6.30171>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<3.2967, -4.53965, -6.97158>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<4.29669, -3.59153, -7.53007>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<5.29669, -2.58241, -7.96885>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<6.29669, -1.52734, -8.28138>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<7.29669, -0.442048, -8.46299>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-2.83729, -7.94891, -0.537396>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-1.83728, -7.75951, -1.55932>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-0.837283, -7.44697, -2.55055>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<0.162717, -7.01597, -3.49631>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<1.16272, -6.47291, -4.38249>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<2.16272, -5.82591, -5.19588>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<3.16272, -5.08461, -5.92436>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<4.16272, -4.26005, -6.55706>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<5.16272, -3.36453, -7.08456>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<6.16272, -2.4114, -7.499>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<7.16272, -1.41487, -7.79419>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<8.16272, -0.389784, -7.96573>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-2.02827, -7.36551, -0.465763>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-1.02827, -7.18918, -1.41713>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-0.028268, -6.89823, -2.33991>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<0.971732, -6.49698, -3.22036>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<1.97173, -5.99143, -4.04535>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<2.97173, -5.3891, -4.80257>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<3.97173, -4.69899, -5.48075>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<4.97174, -3.93137, -6.06977>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<5.97173, -3.09768, -6.56084>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<6.97173, -2.21036, -6.94666>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<7.97173, -1.28264, -7.22148>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<8.97173, -0.328344, -7.38116>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<-1.28513, -6.70136, -0.384217>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-0.285125, -6.53993, -1.25525>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<0.714875, -6.27354, -2.10012>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<1.71487, -5.90618, -2.90622>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<2.71488, -5.44331, -3.66156>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<3.71488, -4.89184, -4.35484>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<4.71488, -4.26, -4.97575>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<5.71488, -3.55719, -5.51503>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<6.71488, -2.7939, -5.96465>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<7.71488, -1.98151, -6.31789>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<8.71488, -1.13212, -6.56949>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<9.71488, -0.258401, -6.7157>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<-0.615998, -5.96376, -0.29365>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<0.384004, -5.81886, -1.07547>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<1.384, -5.57976, -1.8338>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<2.384, -5.25002, -2.55734>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<3.38401, -4.83456, -3.23531>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<4.384, -4.33958, -3.85758>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<5.384, -3.77246, -4.41489>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<6.38401, -3.14163, -4.89894>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<7.384, -2.45652, -5.3025>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<8.384, -1.72734, -5.61956>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<9.384, -0.96495, -5.8454>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<10.384, -0.180721, -5.97663>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<-0.0282139, -5.16077, -0.195056>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<0.971788, -5.03388, -0.879749>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<1.97179, -4.82448, -1.54387>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<2.97179, -4.5357, -2.17753>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<3.97179, -4.17186, -2.77127>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<4.97179, -3.73836, -3.31624>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<5.97179, -3.24169, -3.80432>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<6.97179, -2.68924, -4.22824>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<7.97179, -2.08924, -4.58166>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<8.97179, -1.45064, -4.85933>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<9.97179, -0.782961, -5.05712>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<10.9718, -0.0961557, -5.17204>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<0.471785, -4.3012, -0.0895144>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<1.47179, -4.19358, -0.670239>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<2.47179, -4.01597, -1.23352>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<3.47179, -3.77105, -1.77095>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<4.47179, -3.46245, -2.27454>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<5.47179, -3.09478, -2.73676>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<6.47179, -2.67353, -3.15073>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<7.47179, -2.20496, -3.51027>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<8.47179, -1.69607, -3.81003>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<9.47179, -1.15444, -4.04554>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<10.4718, -0.588147, -4.21329>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<11.4718, -0.00563139, -4.31076>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<0.87852, -3.39447, 0.0218186>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<1.87852, -3.30717, -0.449233>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<2.87852, -3.16311, -0.906133>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<3.87852, -2.96444, -1.34207>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<4.87852, -2.71412, -1.75055>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<5.87852, -2.41589, -2.12548>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<6.87852, -2.07419, -2.46126>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<7.87852, -1.69411, -2.75291>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<8.87852, -1.28133, -2.99605>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<9.87852, -0.84199, -3.18709>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<10.8785, -0.382645, -3.32316>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<11.8785, 0.0898601, -3.40222>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<1.18754, -2.4505, 0.137723>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<2.18754, -2.38436, -0.219152>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<3.18754, -2.27522, -0.565305>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<4.18754, -2.1247, -0.895578>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<5.18754, -1.93506, -1.20505>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<6.18754, -1.70912, -1.4891>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<7.18754, -1.45024, -1.74349>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<8.18754, -1.16229, -1.96445>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<9.18754, -0.849559, -2.14866>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<10.1875, -0.51671, -2.29339>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<11.1875, -0.168704, -2.39648>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<12.1875, 0.189273, -2.45638>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<1.39545, -1.47965, 0.256929>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<2.39545, -1.43527, 0.0174828>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<3.39545, -1.36204, -0.214769>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<4.39545, -1.26105, -0.436367>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<5.39545, -1.13381, -0.64401>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<6.39545, -0.982212, -0.834589>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<7.39545, -0.808521, -1.00528>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<8.39545, -0.615319, -1.15353>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<9.39545, -0.40549, -1.27712>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<10.3955, -0.182164, -1.37423>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<11.3955, 0.0513314, -1.4434>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<12.3955, 0.291517, -1.48359>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<1.49998, -0.49254, 0.378131>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<2.49998, -0.470293, 0.258079>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<3.49998, -0.433576, 0.141634>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<4.49998, -0.382945, 0.0305313>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<5.49998, -0.319148, -0.0735766>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<6.49998, -0.24314, -0.169125>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<7.49998, -0.156057, -0.254705>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<8.49998, -0.0591908, -0.329036>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<9.49998, 0.0460133, -0.391001>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<10.5, 0.157982, -0.439687>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<11.5, 0.27505, -0.474368>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<12.5, 0.395473, -0.494521>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<1.49998, 0.500004, 0.5>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<2.49998, 0.500001, 0.5>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<3.49998, 0.500003, 0.500001>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<4.49998, 0.500001, 0.500001>, 0.5}
  T810 (<0.866667,0.795804,0.394248>)
}
		
object {   
  sphere {<5.49998, 0.500002, 0.499999>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<6.49998, 0.500004, 0.500004>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<7.49998, 0.500001, 0.500003>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
		
object {   
  sphere {<8.49998, 0.500001, 0.5>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<9.49998, 0.500003, 0.500003>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<10.5, 0.500001, 0.500004>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<11.5, 0.500001, 0.500001>, 0.5}
  T810 (<0.306805,0.372472,0.588235>)
}
		
object {   
  sphere {<12.5, 0.500001, 0.499999>, 0.5}
  T810 (<0.485592,0.273541,0.576471>)
}
scale 3
}

object {nw translate (max_extent (nw)+min_extent (nw))*-0.5}

plane {y, (max_extent (nw).y-min_extent (nw).y)*-0.5 finish {reflection {0, 1}}}

		